#!/bin/bash

function check_xml() 
{
  if test -f $trans_doc; then
    case $trans_doc in
      */api/index.docbook) ;;
      */index.docbook)
        if ! SGML_CATALOG_FILES=$KDEDIR/share/apps/ksgmltools2/customization/catalog xmllint --valid --noout --catalogs $trans_doc > /dev/null 2>&1 ; then
          echo "REMOVING $trans_doc"
          rm -f $trans_doc
        fi
        ;;
      *) ;;
    esac
  fi
}

LANG=C
LC_ALL=C
LC_MESSAGES=C
CDPATH=

modules=`find documentation/ -maxdepth 1 -type d -follow -printf '%f\n' | grep -v svn | grep -v documentation`

all_files=""

if test ! -f $KDEDIR/share/apps/ksgmltools2/customization/catalog; then
  echo '$KDEDIR/share/apps/ksgmltools2/customization/catalog does not exist. Aborting.'
  exit 1
fi

if ! type -p xml2pot >/dev/null; then
  echo 'xml2pot needs to be in your PATH. See kdesdk/poxml'
  exit 1
fi

for m in $modules; do
  echo $m
  files_in_module=""
  files=`( cd documentation/ && find $m -follow -name "*.docbook")`
  all_files="$all_files $files"
  ### FIXME: we would need to create the svn directory instead
  mkdir -p templates/docmessages/$m
  for i in $files; do
    case $i in
      *_original.docbook)
        continue
        ;;
    esac
    j=`echo $i | sed -e "s#$m/##" | sed -e 's#.docbook$##' | sed -e 's#/index$##' | sed -e "s#/#_#g"`
    test -n "$VERBOSE" && echo "xml2pot $i > $j.pot" || echo -e ."\c"
    xml2pot documentation/$i > templates/docmessages/$m/$j.pot.new
    if test ! -s templates/docmessages/$m/$j.pot.new; then
        test -n "$VERBOSE" && echo "Generating $j.pot has failed!"
        continue
    fi
    LC_ALL=C svn info documentation/$i > templates/docmessages/$m/$j.pot.info
    svnrevision=`sed -n -e "/^Last Changed Rev: / { s/^Last Changed Rev: //; p }" < templates/docmessages/$m/$j.pot.info`
    svnurl=`sed -n -e "/^URL: / { s,URL:.*/home/kde/,,; p }" < templates/docmessages/$m/$j.pot.info`
    rm -f templates/docmessages/$m/$j.pot.info
    cat templates/docmessages/$m/$j.pot.new | sed -e "/^\"Report-Msgid-Bugs-To:/ a \"X-KDE-DocBook-SVN-Changed-Revision: $svnrevision\\\\n\"" | sed -e "/^\"Report-Msgid-Bugs-To:/ a \"X-KDE-DocBook-SVN-URL: $svnurl\\\\n\"" > templates/docmessages/$m/$j.pot.new2
    if test -s templates/docmessages/$m/$j.pot.new2; then
        mv templates/docmessages/$m/$j.pot.new2 templates/docmessages/$m/$j.pot.new
    else
        echo "Warning: could not insert SVN info in $j.pot!"
    fi
    python ./scripts/msgsplit templates/docmessages/$m/$j.pot.new
    if test -s templates/docmessages/$m/$j.pot.new; then
      if test ! -f templates/docmessages/$m/$j.pot; then
        test -n "$VERBOSE" && echo "$j.pot is new!"
        mv templates/docmessages/$m/$j.pot.new templates/docmessages/$m/$j.pot
        test -n "$AUTOSVNADD" && svn add templates/docmessages/$m/$j.pot
      elif ! diff -q -I^\"POT-Creation-Date: templates/docmessages/$m/$j.pot.new templates/docmessages/$m/$j.pot > /dev/null; then
        mv templates/docmessages/$m/$j.pot.new templates/docmessages/$m/$j.pot
      else
        rm templates/docmessages/$m/$j.pot.new
      fi
      files_in_module="$files_in_module $j.pot ";
    fi
  done

  for one_file in `ls templates/docmessages/$m`; do
    ex=`echo " $files_in_module " | sed -n "/ $one_file /p"`
    if test "$ex" != " $files_in_module "; then
      delete_file="$m/$one_file";
      echo
      echo "This file seems to be obsolete: $delete_file";
      svn del templates/docmessages/$delete_file
    fi
  done
  echo
done
